.. _supported-monte-carlo-programs:

==============================
Supported Monte Carlo programs
==============================

Here are the currently supported Monte Carlo programs in **pyMonteCarlo**.

.. _supported-monte-carlo-programs-casino2:

Casino 2
========

Authors
    Dominique Drouin, Alexandre Real Couture, Raynald Gauvin, Pierre Hovington,
    Paula Horny, Hendrix Demers, Dany Joly, Philippe Drouin and
    Nicolas Poirier-Demers

Version
    2.5.1.0 (2017)

Website
    `http://www.gel.usherbrooke.ca/casino <http://www.gel.usherbrooke.ca/casino>`_

Supported platforms
    * Windows
    * MacOS (using *Wine*, see :ref:`installation <installation-wine>`)
    * Linux (using *Wine*, see :ref:`installation <installation-wine>`)

Python package dependencies
    * pycasinotools
      (`code <https://github.com/drix00/pycasinotools>`_ |
      `documentation <https://pycasinotools.readthedocs.io>`_)
    * pymontecarlo-casino2

Installation
    *Casino 2* is distributed inside *pymontecarlo-casino2*.
    No installation step is needed.

